#!/usr/bin/env lua
require ("nixio.fs")


local port_index = {"2", "1"}
local sysfs_device_present = "/sys/devices/platform/1e1c0000.xhci/usb1/1-%s"

local sysfs_idVendor = "/sys/devices/platform/1e1c0000.xhci/usb1/1-%s/idVendor"
local sysfs_idProduct = "/sys/devices/platform/1e1c0000.xhci/usb1/1-%s/idProduct"


local table_vid_pid = {}
table_vid_pid["2c7c:0700"] = 1

function trim(s)
	if s == nil then return "" end
   return (s:gsub("^%s*(.-)%s*$", "%1"))
end

function popen_str(cli_str)
	local out
	f = io.popen (cli_str)
	out = f:read('*all')
	f:close()
	return out
end


function cat_sysfs(path)
	local out
	return popen_str ("cat ".. path)
	
end

function device_present(idx)
	if port_index[idx] then
		local device = string.format(sysfs_device_present, port_index[idx])
		local ret = nixio.fs.access(device)
		if ret then
			return ret
		else 
			return false
		end
	else
		return false
	end
end


function find_id_vendor(idx)
	if port_index[idx] then
		return trim(cat_sysfs(string.format(sysfs_idVendor, port_index[idx])))
	else
		return ""
	end
end

function find_id_product(idx)
	if port_index[idx] then
		return trim(cat_sysfs(string.format(sysfs_idProduct, port_index[idx])))
	else
		return ""
	end
end

function vendorid_productid(idx)
	local idVendor, idProduct = find_id_vendor(idx), find_id_product(idx)
	local product_code = idVendor..":"..idProduct
	return product_code
end



function modem_type(idx)
	local device_present = device_present(idx)
	print("Device present ", idx, device_present)
	if device_present then
		local product_code = vendorid_productid(idx)
		if table_vid_pid[product_code] ~= nil then
			 
			local unbind_cmd = string.format('echo "1-%s:1.3" > /sys/bus/usb/drivers/option/unbind', port_index[idx])
			local bind_cmd = 'echo "2c7c 0700" > /sys/bus/usb/drivers/qmi_wwan/new_id'
			local f
			f = io.popen (unbind_cmd)
			f:close()

			f = io.popen (bind_cmd)
			f:close()

			f = io.popen ("sleep 1")
			f:close()
		end
	end
end
print("Checking if BG95 is present and bind CDC-WDM driver")
modem_type(1)
modem_type(2)
